@@ -5,7 +5,7 @@ from urlparse import urlparse
 from functools import wraps
 
 from .things import Blob, ListBlob, Account, identify_thing
-from .util import relative_url, pull_data_dict
+from .util import relative_url, pull_data_dict, html_unicode_unescape
 from .exceptions import NotLoggedIn, BadResponse, PostError, LoginFail
 from .const import DEFAULT_USER_AGENT, LOGIN_URL, POST_ERROR_PATTERN, API_PERIOD, SUBMIT_RESPONSE_LINK_PATTERN
 
@@ -70,7 +70,7 @@ class Reddit(object):
             self.login(username, password)
     
     def __repr__(self):
-        return '<Reddit [{}]>'.format(self._username or '(not logged in)')
+        return '<Reddit [{0}]>'.format(self._username or '(not logged in)')
     
     def _inject_request_kwargs(self, kwargs):
         if self._cookies:
@@ -97,6 +97,8 @@ class Reddit(object):
             elif isinstance(v, list):
                 retval = ListBlob(self, items=[self._thingify(o, path) for o in v])
                 retval._path = path
+            elif isinstance(v, basestring):
+                retval = html_unicode_unescape(v)
             else:
                 retval = v
             return retval
@@ -876,4 +878,4 @@ class Reddit(object):
 
 def connect(*args, **kwargs):
     """Just an alias to instantiate :class:`Reddit`, really."""
-    return Reddit(*args, **kwargs)
\ No newline at end of file
+    return Reddit(*args, **kwargs)
