@@ -1,3 +1,4 @@
+import re
 from .const import BASE_URL, KIND_PATTERN, TYPES
 
 
@@ -13,15 +14,18 @@ def limstr(s, max_length):
     else:
         return s
 
+
 def urljoin(*args):
     return u'/'.join(unicode(a).strip('/') for a in args)
 
+
 def relative_url(*args):
     url = urljoin(BASE_URL, *args)
     if not url.endswith(u'.json'):
         url += u'/.json'
     return url
 
+
 def kind(s):
     m = KIND_PATTERN.match(s)
     if m:
@@ -29,6 +33,7 @@ def kind(s):
     else:
         return s
 
+
 def pull_data_dict(lst):
     if not isinstance(lst, list):
         raise TypeError('lst must be a list')
@@ -39,4 +44,10 @@ def pull_data_dict(lst):
                 return v
         elif isinstance(i, dict) and 'data' in i:
             return i
-    return None
\ No newline at end of file
+    return None
+
+
+def html_unicode_unescape(s):
+    def f(matchobj):
+        return unichr(int(matchobj.group(1)))
+    return re.sub(r'&amp;#(\d+);', f, s)
\ No newline at end of file
